<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for Code.SDGInformationsbereich StructType
 * Meta information extracted from the WSDL
 * - documentation: Codes der Informationsbereiche, die für Bürger und Unternehmen relevant sind, die ihre Binnenmarktrechte ausüben. Nach VERORDNUNG (EU) 2018/1724 DES EUROPÄISCHEN PARLAMENTS UND DES RATES über die Einrichtung eines einheitlichen
 * digitalen Zugangstors zu Informationen, Verfahren, Hilfs- und Problemlösungsdiensten und zur Änderung der Verordnung (EU) Nr. 1024/2012 (SDG)
 * @subpackage Structs
 */
class Code_SDGInformationsbereich extends AbstractStructBase
{
    /**
     * The listVersionID
     * Meta information extracted from the WSDL
     * - documentation: Die konkrete Version der zu nutzenden Codeliste wird mit diesem XML-Attribut übertragen.Analog zum listURI ist die Bestimmung der Version einer Codeliste bei der Übertragung eines Codes zwingend. Die Version kann jedoch ebenfalls
     * bereits im XÖV-Standard festgelegt werden (es handelt sich in diesem Fall um einen Code-Typ 1 oder 2). | Dokumentation aus XÖV-Bibliothek:
     * - use: required
     * @var string
     */
    public $listVersionID;
    /**
     * The code
     * Meta information extracted from the WSDL
     * - documentation: In diesem XML-Element wird der Code einer Codeliste übermittelt. | Dokumentation aus XÖV-Bibliothek:
     * - form: unqualified
     * @var string
     */
    public $code;
    /**
     * The name
     * Meta information extracted from the WSDL
     * - documentation: Mit diesem optionalen XML-Element kann die Beschreibung des Codes, wie in der jeweiligen Beschreibungsspalte der Codeliste vorgegeben, übermittelt werden. | Dokumentation aus XÖV-Bibliothek:
     * - form: unqualified
     * - minOccurs: 0
     * @var string
     */
    public $name;
    /**
     * The listURI
     * Meta information extracted from the WSDL
     * - documentation: Mit diesem XML-Attribut wird die Kennung der Codeliste übermittelt, in deren Kontext der jeweilige Code zu interpretieren ist. Die Kennung identifiziert die Codeliste, nicht jedoch deren Version eindeutig.Wird bereits im Rahmen des
     * XÖV-Standards eine Kennung vorgegeben (es handelt sich in diesem Fall um einen Code-Typ 1, 2 oder 3) darf auf eine nochmalige Angabe der Kennung bei der Übermittlung eines Codes verzichtet werden. Aus diesem Grund ist das XML-Attribut listURI
     * zunächst als optional deklariert. | Dokumentation aus XÖV-Bibliothek:
     * - fixed: urn:xoev-de:fim:codeliste:sdginformationsbereich
     * - use: optional
     * @var string
     */
    public $listURI;
    /**
     * Constructor method for Code.SDGInformationsbereich
     * @uses Code_SDGInformationsbereich::setListVersionID()
     * @uses Code_SDGInformationsbereich::setCode()
     * @uses Code_SDGInformationsbereich::setName()
     * @uses Code_SDGInformationsbereich::setListURI()
     * @param string $listVersionID
     * @param string $code
     * @param string $name
     * @param string $listURI
     */
    public function __construct($listVersionID = null, $code = null, $name = null, $listURI = null)
    {
        $this
            ->setListVersionID($listVersionID)
            ->setCode($code)
            ->setName($name)
            ->setListURI($listURI);
    }
    /**
     * Get listVersionID value
     * @return string
     */
    public function getListVersionID()
    {
        return $this->listVersionID;
    }
    /**
     * Set listVersionID value
     * @param string $listVersionID
     * @return \StructType\Code_SDGInformationsbereich
     */
    public function setListVersionID($listVersionID = null)
    {
        // validation for constraint: string
        if (!is_null($listVersionID) && !is_string($listVersionID)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($listVersionID, true), gettype($listVersionID)), __LINE__);
        }
        $this->listVersionID = $listVersionID;
        return $this;
    }
    /**
     * Get code value
     * @return string|null
     */
    public function getCode()
    {
        return $this->code;
    }
    /**
     * Set code value
     * @param string $code
     * @return \StructType\Code_SDGInformationsbereich
     */
    public function setCode($code = null)
    {
        // validation for constraint: string
        if (!is_null($code) && !is_string($code)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($code, true), gettype($code)), __LINE__);
        }
        $this->code = $code;
        return $this;
    }
    /**
     * Get name value
     * @return string|null
     */
    public function getName()
    {
        return $this->name;
    }
    /**
     * Set name value
     * @param string $name
     * @return \StructType\Code_SDGInformationsbereich
     */
    public function setName($name = null)
    {
        // validation for constraint: string
        if (!is_null($name) && !is_string($name)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($name, true), gettype($name)), __LINE__);
        }
        $this->name = $name;
        return $this;
    }
    /**
     * Get listURI value
     * @return string|null
     */
    public function getListURI()
    {
        return $this->listURI;
    }
    /**
     * Set listURI value
     * @param string $listURI
     * @return \StructType\Code_SDGInformationsbereich
     */
    public function setListURI($listURI = null)
    {
        // validation for constraint: string
        if (!is_null($listURI) && !is_string($listURI)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($listURI, true), gettype($listURI)), __LINE__);
        }
        $this->listURI = $listURI;
        return $this;
    }
}
